#ifndef LIB_MODULE_INCLUDED
#define LIB_MODULE_INCLUDED

/*!***************************************************************************************
 * @file	module.h
 * @brief	header file for the library for module bla
 * @version	1.00
 * @date	10-Mar-2014
 ******************************************************************************************
 */

/**
 * @defgroup module_hi High Level API for module bla
 * @brief this is the high level API for module bla, this are the recommended
 * functions to use when communicating with the module.
 * @details
 * The high level API methods provide a much simpler, better readable and less
 * error prone interface to the module.
 */

/**
 * @ingroup module_hi
 * @brief read the power measured on the provided port number
 * @param [in] id is the identifier for the N7745, 0 <= id < SE_GPIB_N7745_MAX
 * @param [in] nPort is the port number, SE_GPIB_N7745_PORT_MIN <= nPort <= SE_GPIB_N7745_PORT_MAX
 * @return measurement value or SE_GPIB_ERROR_VALUE on error
 * @details Reads the current power meter value. It provides its own software triggering and does not
 * need a triggering command.
 *
 * @example main.c
 */
extern const float ReadPower(const int id, const int nPort);

 #endif
 